## Hivemind

[![Build status](https://circleci.com/gh/learning-at-home/hivemind.svg?style=shield)](https://circleci.com/gh/learning-at-home/hivemind)
[![Documentation Status](https://readthedocs.org/projects/learning-at-home/badge/?version=latest)](https://learning-at-home.readthedocs.io/en/latest/?badge=latest)

Distributed training of large neural networks across volunteer computers.

![img](https://i.imgur.com/GPxolxb.gif)

**[WIP]** - this branch is a work in progress. If you're interested in
supplementary code for [Learning@home paper](https://arxiv.org/abs/2002.04013),
you can find it at https://github.com/mryab/learning-at-home.
